#' @name ICSClust-package
#'
#' @title \packageTitle{ICSClust}
#'
#' @description \packageDescription{ICSClust}
#'
#' @details
#' The DESCRIPTION file:
#' \packageDESCRIPTION{ICSClust}
#' \packageIndices{ICSClust}
#'
#' @references
#' Alfons, A., Archimbaud, A., Nordhausen, K., & Ruiz-Gazen, A. (2024). 
#' Tandem clustering with invariant coordinate selection. 
#' Econometrics and Statistics.
#'  \doi{10.1016/j.ecosta.2024.03.002}.
#'
#' @author
#' \packageAuthor{ICSClust}
#'
#' Maintainer: \packageMaintainer{ICSClust}
#'
#' @keywords package
"_PACKAGE"